@@ -24,7 +24,7 @@ except ImportError:
 TEXT_ENDPOINT = "https://api.houndify.com/v1/text"
 VOICE_ENDPOINT = "https://api.houndify.com/v1/audio"
 TRANSCRIPTION_ENDPOINT = "https://transcription.houndify.com/v1/transcription"
-VERSION = "2.0.14"
+VERSION = "2.1.0"
 
 
 class HoundifySDKError(Exception):
@@ -201,16 +201,6 @@ class HoundListener(object):
         Only occurs in live transcription mode.
         """
         pass
-    def onEntityIdentification(self, entities, transcript):
-        """
-        onEntityIdentification is fired once the server has detected an entity.
-        """
-        pass
-    def onTopicIdentification(self, topics, transcript):
-        """
-        onTopicIdentification is fired once the server has detected a topic.
-        """
-        pass
     def onPartialTranscriptProperties(self, transcript, props):
         """
         onPartialTranscriptProperties is fired when the server has a partial transcript
